@@ -1,4 +1,4 @@
-{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE OverloadedStrings, CPP #-}
 
 module Network.Wai.Application.Classic.EventSource (
     bodyToEventSource
@@ -46,7 +46,11 @@ splitDoubleLineBreak str = go str 0
                                     in xs:go ys 0
             | otherwise = [bs]
 
+#if MIN_VERSION_conduit(1,3,0)
+eventSourceConduit :: ConduitT ByteString (Flush Builder) IO ()
+#else
 eventSourceConduit :: Conduit ByteString IO (Flush Builder)
+#endif
 eventSourceConduit = CL.concatMapAccum f ""
   where
     f input rest = (last xs, concatMap addFlush $ init xs)
@@ -55,5 +59,10 @@ eventSourceConduit = CL.concatMapAccum f ""
         xs = splitDoubleLineBreak (rest `BS.append` input)
 
 -- insert Flush if exists a double line-break
+#if MIN_VERSION_conduit(1,3,0)
+bodyToEventSource :: H.BodyReader -> ConduitT () (Flush Builder) IO ()
+bodyToEventSource br = HC.bodyReaderSource br .| eventSourceConduit
+#else
 bodyToEventSource :: H.BodyReader -> Source IO (Flush Builder)
 bodyToEventSource br = HC.bodyReaderSource br $= eventSourceConduit
+#endif
